@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301  USA.
  *
  * Author:  Roberto Majadas <roberto.majadas@openshine.com>
  */
@@ -36,6 +36,7 @@ struct _NstPluginInfo
 	gchar *id;
 	gchar *description;
 	gboolean never_unload;
+	gboolean can_send_directories;
 	gboolean (*init)(NstPlugin *plugin);
 	GtkWidget* (*get_contacts_widget)(NstPlugin *plugin);
 	gboolean (*validate_destination)(NstPlugin *plugin, GtkWidget *contact_widget, char **error);
